@@ -30,6 +30,7 @@
 #include <sys/types.h>
 #include <elf.h>
 #include ELF_MACHINE_H
+#include "module.h"
 
 #ifndef ElfW
 # if ELFCLASSM == ELFCLASS32
@@ -76,7 +77,7 @@ struct obj_symbol
 {
   struct obj_symbol *next;	/* hash table link */
   const char *name;
-  unsigned long value;
+  tgt_long value;
   unsigned long size;
   int secidx;			/* the defining section index/module */
   int info;
