@@ -1,3 +1,6 @@
+#ifndef MODUTILS_UTIL_H
+#define MODUTILS_UTIL_H 1
+
 /* Miscelaneous utility functions.
    Copyright 1996, 1997 Linux International.
 
@@ -20,11 +23,6 @@
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 
-#ifndef MODUTILS_UTIL_H
-#define MODUTILS_UTIL_H 1
-
-#ident "$Id: util.h 1.2 Fri, 19 Jan 2001 17:26:33 +1100 kaos $"
-
 #include <stdio.h>
 #include <sys/stat.h>
 
@@ -98,4 +96,8 @@ void gzf_close(int fd);
 #define SYMPREFIX "__insmod_";
 extern const char symprefix[10];	/* Must be sizeof(SYMPREFIX), including nul */
 
+#if defined(ARCH_ia64) || defined(ARCH_ppc64)
+#define HAS_FUNCTION_DESCRIPTORS
+#endif
+
 #endif /* util.h */
